@@ -57,7 +57,7 @@
 #include <init.h>
 #include <driver.h>
 #include <sizes.h>
-#include <asm/io.h>
+#include <io.h>
 #include <ns16550.h>
 #include <asm/armlinux.h>
 #include <generated/mach-types.h>
