@@ -35,7 +35,7 @@
 #include <nand.h>
 #include <command.h>
 #include <spi/spi.h>
-#include <asm/io.h>
+#include <io.h>
 #include <mach/imx-nand.h>
 #include <mach/imx-pll.h>
 #include <mach/imxfb.h>
