@@ -24,7 +24,7 @@
 #ifndef __INCLUDE_ARCH_DEBUG_LL_H__
 #define   __INCLUDE_ARCH_DEBUG_LL_H__
 
-#include <asm/io.h>
+#include <io.h>
 #include <mach/hardware.h>
 
 #define rbr		0
