@@ -73,17 +73,6 @@ static void cookmode(void)
 	tcsetattr(0, TCSANOW, &term_orig);
 }
 
-void linux_putc(const char c)
-{
-	fputc(c, stdout);
-
-	/* If \n, also do \r */
-	if (c == '\n')
-		linux_putc ('\r');
-
-	fflush(stdout);
-}
-
 int linux_tstc(int fd)
 {
 	struct timeval tv = {
@@ -117,15 +106,6 @@ int ctrlc(void)
 	return 0;
 }
 
-int linux_getc(void)
-{
-	char ret;
-
-	read(0, &ret, 1);
-
-	return ret;
-}
-
 uint64_t linux_get_time(void)
 {
 	struct timespec ts;
@@ -256,10 +236,10 @@ static int add_image(char *str, char *name)
 	hf->name = strdup(name);
 
 	if (map) {
-		hf->map_base = (unsigned long)mmap(NULL, hf->size,
+		hf->base = (unsigned long)mmap(NULL, hf->size,
 				PROT_READ | (readonly ? 0 : PROT_WRITE),
 				MAP_SHARED, fd, 0);
-		if ((void *)hf->map_base == MAP_FAILED)
+		if ((void *)hf->base == MAP_FAILED)
 			printf("warning: mmapping %s failed\n", file);
 	}
 
