@@ -46,9 +46,10 @@
 #include <init.h>
 #include <miidev.h>
 #include <errno.h>
-#include <asm/io.h>
+#include <io.h>
 #include <mach/board.h>
 #include <linux/clk.h>
+#include <linux/err.h>
 
 #include "macb.h"
 
@@ -392,7 +393,7 @@ static int macb_get_ethaddr(struct eth_device *edev, unsigned char *adr)
 
 static int macb_set_ethaddr(struct eth_device *edev, unsigned char *adr)
 {
-	struct macb_device *macb = edev->priv; 
+	struct macb_device *macb = edev->priv;
 
 	debug("%s\n", __func__);
 
@@ -444,7 +445,7 @@ static int macb_probe(struct device_d *dev)
 	macb->miidev.parent = dev;
 	macb->flags = pdata->flags;
 
-	macb->rx_buffer = xmalloc(CFG_MACB_RX_BUFFER_SIZE); 
+	macb->rx_buffer = xmalloc(CFG_MACB_RX_BUFFER_SIZE);
 	macb->rx_ring = xmalloc(CFG_MACB_RX_RING_SIZE * sizeof(struct macb_dma_desc));
 	macb->tx_ring = xmalloc(sizeof(struct macb_dma_desc));
 
@@ -456,6 +457,11 @@ static int macb_probe(struct device_d *dev)
 	 */
 #if defined(CONFIG_ARCH_AT91)
 	pclk = clk_get(dev, "macb_clk");
+	if (IS_ERR(pclk)) {
+		dev_err(dev, "no macb_clk\n");
+		return PTR_ERR(pclk);
+	}
+
 	clk_enable(pclk);
 	macb_hz = clk_get_rate(pclk);
 #else
@@ -479,15 +485,15 @@ static int macb_probe(struct device_d *dev)
 }
 
 static struct driver_d macb_driver = {
-        .name  = "macb",
-        .probe = macb_probe,
+	.name  = "macb",
+	.probe = macb_probe,
 };
 
 static int macb_driver_init(void)
 {
 	debug("%s\n", __func__);
-        register_driver(&macb_driver);
-        return 0;
+	register_driver(&macb_driver);
+	return 0;
 }
 
 device_initcall(macb_driver_init);
