@@ -26,7 +26,7 @@
 #include <driver.h>
 #include <init.h>
 #include <malloc.h>
-#include <asm/io.h>
+#include <io.h>
 
 enum uart_regs {
 	UART_DR              = 0x00,
