@@ -30,7 +30,7 @@
 #include <init.h>
 #include <notifier.h>
 #include <gpio.h>
-#include <asm/io.h>
+#include <io.h>
 #include <mach/imx-regs.h>
 #include <mach/clock.h>
 
