@@ -1,5 +1,5 @@
 
-#if defined CONFIG_ARCH_IMX25 || defined CONFIG_ARCH_IMX35 || defined CONFIG_ARCH_IMX51 || defined CONFIG_X86
+#if defined CONFIG_ARCH_IMX25 || defined CONFIG_ARCH_IMX35 || defined CONFIG_ARCH_IMX51 || defined CONFIG_ARCH_IMX53 || defined CONFIG_X86
 #include <mach/barebox.lds.h>
 #endif
 
@@ -16,7 +16,10 @@
 	KEEP(*(.initcall.5))			\
 	KEEP(*(.initcall.6))			\
 	KEEP(*(.initcall.7))			\
-	KEEP(*(.initcall.8))
+	KEEP(*(.initcall.8))			\
+	KEEP(*(.initcall.9))			\
+	KEEP(*(.initcall.10))			\
+	KEEP(*(.initcall.11))
 
 #define BAREBOX_CMDS	KEEP(*(SORT_BY_NAME(.barebox_cmd*)))
 
