@@ -204,6 +204,13 @@ struct device_d *add_generic_device(const char* devname, int id, const char *res
 		resource_size_t start, resource_size_t size, unsigned int flags,
 		void *pdata);
 
+/*
+ * register a generic device
+ * with multiple resources
+ */
+struct device_d *add_generic_device_res(const char* devname, int id,
+		struct resource *res, int nb, void *pdata);
+
 /*
  * register a memory device
  */
